import QtQuick 1.1
import qb.components 1.0
import BasicUIControls 1.0

Tile {
	id: humidityNowTile

	property ThermostatApp app;

	/// Will be called when widget instantiated
	function init() {}

	onClicked: {
		app.showHumidityPopup();
		countly.sendPageViewEvent(util.absoluteToRelativePath(widgetInfo.url) + ":humidityExplanationPopup");
	}

	Text {
		id: titleText
		text: qsTr("Humidity")
		anchors {
			baseline: parent.top
			baselineOffset: 30
			horizontalCenter: parent.horizontalCenter
		}
		font {
			family: qfont.regular.name
			pixelSize: qfont.tileTitle
		}
		color: colors.tileTitleColor
	}

	Image {
		id: humidityIcon
		anchors.centerIn: parent
		source: dimState ? "drawables/humidity_dim.svg" : "drawables/humidity.svg"

		scale: 0.6
		smooth: true
	}

	StyledProgressRing {
		id: progressRing
		anchors.centerIn: parent

		backgroundColor: colors.dayTileBackgroundBar
		fillColor: chooseColor(app.humidity)
		radius: 40
		thickness: 8
		gap: 10
		gapPosition: StyledProgressRing.Bottom

		progress: app.humidity

		mouseEnabled: false

		function chooseColor(percentage) {
			if (dimState) {
				return "#ffffff";
			} else if (percentage <= 20) {
				return "#e64f0a";
			} else if (percentage <= 40) {
				return "#FF9900";
			} else if (percentage <= 60) {
				return "#689F38";
			} else if (percentage <= 80) {
				return "#FF9900";
			} else {
				return "#e64f0a";
			}
		}
	}

	Text {
		id: valueText
		text: i18n.number(app.humidity, 0) + "%"
		anchors {
			baseline: parent.bottom
			baselineOffset: -16
			horizontalCenter: parent.horizontalCenter
		}
		font {
			family: qfont.regular.name
			pixelSize: qfont.tileText
		}
		color: colors.tileTextColor
	}
}
