import QtQuick 1.1
import Effects 1.0
import qb.components 1.0

Tile {
	id: humidityNowTile

	property ThermostatApp app;

	/// Will be called when widget instantiated
	function init() {
		app.humidityChanged.connect(stateItem.updateState);
	}

	Component.onDestruction: {
		app.humidityChanged.disconnect(stateItem.updateState);
	}

	onClicked: {
		app.showHumidityPopup();
		countly.sendPageViewEvent(util.absoluteToRelativePath(widgetInfo.url) + ":humidityExplanationPopup");
	}

	onAppChanged: {
		stateItem.updateState();
	}

	Item {
		id: stateItem

		function updateState() {
			var percentage = app.humidity;
			if (percentage < 20) {
				state = "tooLow";
			} else if (percentage < 40) {
				state = "low";
			} else if (percentage < 60) {
				state = "ok";
			} else if (percentage < 80) {
				state = "high";
			} else {
				state = "tooHigh";
			}
		}

		states: [
			State {
				name: "tooLow"
				PropertyChanges { target: verdictText; text: qsTr("Too low") }
				PropertyChanges { target: humidityIcon; source: "drawables/humidity-toolow.svg" }
			},
			State {
				name: "low"
				PropertyChanges { target: verdictText; text: qsTr("Low") }
				PropertyChanges { target: humidityIcon; source: "drawables/humidity-low.svg" }
			},
			State {
				name: "ok"
				PropertyChanges { target: verdictText; text: qsTr("Healthy") }
				PropertyChanges { target: humidityIcon; source: "drawables/humidity-healthy.svg" }
			},
			State {
				name: "high"
				PropertyChanges { target: verdictText; text: qsTr("High") }
				PropertyChanges { target: humidityIcon; source: "drawables/humidity-high.svg" }
			},
			State {
				name: "tooHigh"
				PropertyChanges { target: verdictText; text: qsTr("Too high") }
				PropertyChanges { target: humidityIcon; source: "drawables/humidity-toohigh.svg" }
			}
		]
	}


	Text {
		id: titleText
		text: qsTr("Humidity")
		anchors {
			baseline: parent.top
			baselineOffset: 30
			horizontalCenter: parent.horizontalCenter
		}
		font {
			family: qfont.regular.name
			pixelSize: qfont.tileTitle
		}
		color: colors.tileTitleColor
	}

	Image {
		id: humidityIcon
		anchors.centerIn: parent
		source: "drawables/humidity.svg"
		height: 80
		fillMode: Image.PreserveAspectFit

		onSourceChanged: resize()
		onHeightChanged: resize()
		onStatusChanged: resize()

		function resize() {
			if (status === Image.Ready && height) {
				sourceSize = undefined;
				sourceSize.height = height;
				sourceSize.width = 0;
			}
		}

		effect: Colorize { strength: canvas.dimState ? 1.0 : 0.0; color: colors.dayTileAverageBar }
	}

	Text {
		id: verdictText
		text: ""
		anchors {
			baseline: parent.bottom
			baselineOffset: -16
			horizontalCenter: parent.horizontalCenter
		}
		font {
			family: qfont.regular.name
			pixelSize: qfont.tileText
		}
		color: colors.tileTextColor
	}
}
